==> benno-web-2.10.3.tgz: srv/benno/bennoweb/htdocs/view/default.php <==
<?php
/*
 * Benno MailArchiv
 *
 * Copyright  2008-2012 LWsystems GmbH & Co. KG
 *
 * http://www.lw-systems.de/
 * http://www.benno-mailarchiv.de/
 *
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3
 * as published by the Free Software Foundation.
 *
 * Binary versions of this file provided by LWsystems to you as
 * well as other copyrighted, protected or trademarked materials like
 * logos, graphics, fonts, specific documentations and configurations,
 * cryptographic keys etc. are subject to a license agreement between
 * you and LWsystems.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You can find a copy of the GNU Affero General Public License at
 * this URI:
 * http://www.gnu.org/licenses/agpl-3.0.html
 * If not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA  02111-1307  USA
 */

$App->assign('interfaceLanguage',$App->getParam('LANG'));
$App->assign('selectUser',$App->getParam('selectuser'));
$App->assign('auth_error',$auth_error);

if ($App->getConfig('ADMIN_FOUREYES')) {
    $App->assign('ADMIN_FOUREYE',true);
}
if ($App->getConfig('LOGIN_AZURE')) {
    $App->assign('LOGIN_AZURE',true);
    $App->assign('LOGIN_AZURE_LINK',$App->getConfig('LOGIN_AZURE_LINK','/auth/azure'));
}

?>

==> benno-web-2.10.7.tgz: srv/benno/bennoweb/htdocs/view/default.php <==
<?php
/*
 * Benno MailArchiv
 *
 * Copyright  2008-2012 LWsystems GmbH & Co. KG
 *
 * http://www.lw-systems.de/
 * http://www.benno-mailarchiv.de/
 *
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3
 * as published by the Free Software Foundation.
 *
 * Binary versions of this file provided by LWsystems to you as
 * well as other copyrighted, protected or trademarked materials like
 * logos, graphics, fonts, specific documentations and configurations,
 * cryptographic keys etc. are subject to a license agreement between
 * you and LWsystems.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You can find a copy of the GNU Affero General Public License at
 * this URI:
 * http://www.gnu.org/licenses/agpl-3.0.html
 * If not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA  02111-1307  USA
 */

$App->assign('interfaceLanguage',$App->getParam('LANG'));
$App->assign('selectUser',$App->getParam('selectuser'));
$App->assign('auth_error',$auth_error);

if ($App->getConfig('ADMIN_FOUREYES')) {
    $App->assign('ADMIN_FOUREYE',true);
}
if ($App->getConfig('OAUTH2_TPL','/etc/benno-oauth2/assets/login.tpl')) {
    $App->assign('OAUTH2_TPL',$App->getConfig('OAUTH2_TPL','/etc/benno-oauth2/assets/login.tpl'));
}

?>
